var version     = '4.1.0';

const localePacks  = {"en-US":    true,
                       "de-AT":    true  // all possible languages for installation
                      };

const displayName = 'Preferences Toolbar';
const appName     = 'prefbar';
const author      = 'Manuel Reimer';

const jarName     = appName + '.jar';

var installedFiles   = [];
var localesToInstall = [];
var SetupLocaleDB    = null;

function DoLanguageStuff() {
    var languageAttrib = decodeURIComponent(Install.arguments);

    // default setup locale is english
    var SetupLocale = "en-US";

    // if the locale, specified by parameter, is valid, then use it.
    if (languageAttrib in localePacks)
        SetupLocale = languageAttrib;

    // Since PrefBar 3.3.1 we always install *all* locales!
    // A fix in PrefBar ("RepairLanguageSetting" in prefbar.js) will choose
    // the right language after installation.
    for (s in localePacks)
        localesToInstall.push(s);

    // load installer messages
    SetupLocaleDB = loadResources(SetupLocale);
}

function InstallAddon() {
    var err = initInstall(displayName, appName, version);
    if (err != SUCCESS) return SOURCE_DOES_NOT_EXIST;

    DoLanguageStuff();

    var UChrome	= getFolder('Chrome');
    var contentFlag = CONTENT | DELAYED_CHROME;
    var localeFlag  = LOCALE | DELAYED_CHROME;

    var existsInGlobal  = File.exists(getFolder(UChrome, jarName));
    var existsInProfile = File.exists(getFolder(getFolder('Current User', 'chrome'), jarName));
    if (existsInGlobal && existsInProfile) return ALREADY_EXISTS;

    if (existsInProfile ||
       (!existsInGlobal && confirm(SetupLocaleDB.installToChrome))) {
        UChrome = getFolder('Current User', 'chrome');
        contentFlag = CONTENT | PROFILE_CHROME;
        localeFlag  = LOCALE | PROFILE_CHROME;
    }

    logComment('initInstall: ' + err);
    setPackageFolder(UChrome);

    addFile(displayName, 'chrome/' + jarName, UChrome, '');
    var folder = getFolder(UChrome, jarName);
    installedFiles.push(folder);

    // Content
    registerChrome(contentFlag, folder, 'content/'+appName+'/');

    // Language packs
    for (s in localesToInstall)
        registerChrome(localeFlag, folder, 'locale/' + localesToInstall[s] + '/'+appName+'/');

    // ****HACK**** (Mozilla Bug 304800,
    //               Mozilla Bug 204271,
    //               or many other bugs caused by XUL.mfasl)
    // Get sure that the file "XUL.mfasl" get's recreated after restart
    // of mozilla
    // Note that this is normally a task that should be done by xpicleanup,
    // but this is corrupted by Mozilla Bug 304797...
    var profiledir = getFolder("Profile");
    var unixxulcache = getFolder(File.dirGetParent(profiledir), "XUL.mfasl");
    var windowsxulcache = getFolder(profiledir, "XUL.mfl");
    if (File.exists(unixxulcache))
        File.remove(unixxulcache);
    if (File.exists(windowsxulcache))
        File.remove(windowsxulcache);
    // ****END HACK****

    err = getLastError();
    if (err != SUCCESS) {
        alert(SetupLocaleDB.installfailed);
        return err;
    }

    err = performInstall();

    // ****HACK****
    // On linux systems, we get an chrome registration error, if
    // someone tries to update a profile installed PrefBar.
    // We aren't interested in this error, as PrefBar already existed
    // and so the old chrome registration should do the job
    if (existsInProfile && err == CHROME_REGISTRY_ERROR)
        err = SUCCESS;
    // ****END HACK****  

    // ****HACK**** (Mozilla Bug 304797)
    // This bug makes it impossible to overwrite profile-installed
    // extensions if the user doesn't have write access to the mozilla
    // directory. As there is no way to get around this one 
    // automatically, we have to tell the user what's going on and how
    // to get around the bug manually...
    if (existsInProfile && err == ACCESS_DENIED) {
        alert(SetupLocaleDB.bug304797info);
        return err;
    }
    // ****END HACK****

    // Now catch any error, which is no XPInstall bug...
    if (err != SUCCESS && err != REBOOT_NEEDED) {
        alert(SetupLocaleDB.installfailed);
        return err;
    }

    alert('Ver.'+version+'\n\n'+ SetupLocaleDB.installed + '\n' + installedFiles.join('\n') + '\n\n\n' + SetupLocaleDB.complete);
    return SUCCESS;
}

// Start this install script
var status = InstallAddon();
if (status != SUCCESS) cancelInstall(status);
